@@ -1,4 +1,4 @@
-use crate::float_diff_provider::FloatDiffProvider;
+use crate::epsilon_provider::EpsilonProvider;
 use crate::ShouldaEqual;
 use std::borrow::{Borrow, Cow};
 use std::cell::{Cell, RefCell};
@@ -13,10 +13,10 @@ where
     K: ShouldaEqual,
     K: Debug,
 {
-    fn should_eq<FloatDiff: FloatDiffProvider>(&self, other: &Self) -> bool {
+    fn should_eq<Epsilon: EpsilonProvider>(&self, other: &Self) -> bool {
         match (self, other) {
             (None, None) => true,
-            (Some(a), Some(b)) => a.should_eq::<FloatDiff>(b),
+            (Some(a), Some(b)) => a.should_eq::<Epsilon>(b),
             _ => false,
         }
     }
@@ -29,10 +29,10 @@ where
     K: ShouldaEqual,
     K: Debug,
 {
-    fn should_eq<FloatDiff: FloatDiffProvider>(&self, other: &Self) -> bool {
+    fn should_eq<Epsilon: EpsilonProvider>(&self, other: &Self) -> bool {
         match (self, other) {
-            (Err(a), Err(b)) => a.should_eq::<FloatDiff>(b),
-            (Ok(a), Ok(b)) => a.should_eq::<FloatDiff>(b),
+            (Err(a), Err(b)) => a.should_eq::<Epsilon>(b),
+            (Ok(a), Ok(b)) => a.should_eq::<Epsilon>(b),
             _ => false,
         }
     }
@@ -46,8 +46,8 @@ where
     <K as ToOwned>::Owned: Debug,
     K: ?Sized,
 {
-    fn should_eq<FloatDiff: FloatDiffProvider>(&self, other: &Self) -> bool {
-        self.deref().should_eq::<FloatDiff>(other.deref())
+    fn should_eq<Epsilon: EpsilonProvider>(&self, other: &Self) -> bool {
+        self.deref().should_eq::<Epsilon>(other.deref())
     }
 }
 
@@ -56,8 +56,8 @@ where
     T: ShouldaEqual,
     T: ?Sized,
 {
-    fn should_eq<FloatDiff: FloatDiffProvider>(&self, other: &Self) -> bool {
-        self.deref().should_eq::<FloatDiff>(other.deref())
+    fn should_eq<Epsilon: EpsilonProvider>(&self, other: &Self) -> bool {
+        self.deref().should_eq::<Epsilon>(other.deref())
     }
 }
 
@@ -68,8 +68,8 @@ where
     T: Debug,
     T: Copy,
 {
-    fn should_eq<FloatDiff: FloatDiffProvider>(&self, other: &Self) -> bool {
-        self.get().should_eq::<FloatDiff>(&other.borrow().get())
+    fn should_eq<Epsilon: EpsilonProvider>(&self, other: &Self) -> bool {
+        self.get().should_eq::<Epsilon>(&other.borrow().get())
     }
 }
 
@@ -79,8 +79,8 @@ where
     T: ?Sized,
     T: Debug,
 {
-    fn should_eq<FloatDiff: FloatDiffProvider>(&self, other: &Self) -> bool {
-        self.borrow().should_eq::<FloatDiff>(&*other.borrow())
+    fn should_eq<Epsilon: EpsilonProvider>(&self, other: &Self) -> bool {
+        self.borrow().should_eq::<Epsilon>(&*other.borrow())
     }
 }
 
@@ -89,8 +89,8 @@ where
     T: ShouldaEqual,
     T: Debug,
 {
-    fn should_eq<FloatDiff: FloatDiffProvider>(&self, other: &Self) -> bool {
-        self.0.should_eq::<FloatDiff>(&other.0)
+    fn should_eq<Epsilon: EpsilonProvider>(&self, other: &Self) -> bool {
+        self.0.should_eq::<Epsilon>(&other.0)
     }
 }
 
@@ -100,8 +100,8 @@ where
     T: ?Sized,
     T: Debug,
 {
-    fn should_eq<FloatDiff: FloatDiffProvider>(&self, other: &Self) -> bool {
-        (**self).should_eq::<FloatDiff>(&**other)
+    fn should_eq<Epsilon: EpsilonProvider>(&self, other: &Self) -> bool {
+        (**self).should_eq::<Epsilon>(&**other)
     }
 }
 
@@ -111,7 +111,7 @@ where
     T: ?Sized,
     T: Debug,
 {
-    fn should_eq<FloatDiff: FloatDiffProvider>(&self, other: &Self) -> bool {
-        (**self).should_eq::<FloatDiff>(&**other)
+    fn should_eq<Epsilon: EpsilonProvider>(&self, other: &Self) -> bool {
+        (**self).should_eq::<Epsilon>(&**other)
     }
 }
